summaryrefslogtreecommitdiff
path: root/indra/newview/llimfloater.cpp
diff options
context:
space:
mode:
authorOz Linden <oz@lindenlab.com>2012-05-11 12:22:43 -0400
committerOz Linden <oz@lindenlab.com>2012-05-11 12:22:43 -0400
commit9bdb1d82f867147af44def8c1cca3dfb8259b99c (patch)
tree80dfa51fb1fd89e020d25ff88e7df5928e0e13bc /indra/newview/llimfloater.cpp
parentd3ec35fc6c2b8b47336650fe0570995201854a78 (diff)
rename feature from "autocorrect" to "autoreplace", change names accordingly
Diffstat (limited to 'indra/newview/llimfloater.cpp')
-rw-r--r--indra/newview/llimfloater.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/llimfloater.cpp b/indra/newview/llimfloater.cpp
index e300f6f32d..670db3773e 100644
--- a/indra/newview/llimfloater.cpp
+++ b/indra/newview/llimfloater.cpp
@@ -56,7 +56,7 @@
#include "llrootview.h"
#include "llspeakers.h"
#include "llviewerchat.h"
-#include "llautocorrect.h"
+#include "llautoreplace.h"
LLIMFloater::LLIMFloater(const LLUUID& session_id)
: LLTransientDockableFloater(NULL, true, session_id),
@@ -255,8 +255,8 @@ BOOL LLIMFloater::postBuild()
mInputEditor->setMaxTextLength(1023);
// enable line history support for instant message bar
mInputEditor->setEnableLineHistory(TRUE);
- // *TODO Establish LineEditor with autocorrect callback
- mInputEditor->setAutocorrectCallback(boost::bind(&AutoCorrect::autocorrectCallback, AutoCorrect::getInstance(), _1, _2));
+ // *TODO Establish LineEditor with autoreplace callback
+ mInputEditor->setAutoreplaceCallback(boost::bind(&AutoReplace::autoreplaceCallback, AutoReplace::getInstance(), _1, _2));
LLFontGL* font = LLViewerChat::getChatFont();
mInputEditor->setFont(font);